==> ae_parse_date-0.1.0.tar.gz: ae_parse_date-0.1.0/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# parse_date portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_parse_date/master?logo=python)](
    https://gitlab.com/ae-group/ae_parse_date)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_parse_date/coverage.svg)](
    https://ae-group.gitlab.io/ae_parse_date/coverage/ae_parse_date_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_parse_date/mypy.svg)](
    https://ae-group.gitlab.io/ae_parse_date/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_parse_date/pylint.svg)](
    https://ae-group.gitlab.io/ae_parse_date/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_parse_date)](
    https://libraries.io/pypi/ae-parse-date)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/#files)


## installation


Execute the following command for to use the ae.parse_date module in your
application. It will install ae.parse_date into your python (virtual) environment:
 
```shell script
pip install ae-parse-date
```

If you instead want to contribute to this portion then first fork
[the ae_parse_date repository at GitLab](https://gitlab.com/ae-group/ae_parse_date "ae.parse_date code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_parse_date):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.parse_date.html#module-ae.parse_date
"ae_parse_date documentation").

<!-- Common files version 0.1.61 deployed version 0.1.3 (with 0.1.61)
     to https://gitlab.com/ae-group as ae_parse_date module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-parse-date as namespace portion ae-parse-date.
-->

==> ae_parse_date-0.2.2.tar.gz: ae_parse_date-0.2.2/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# parse_date portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_parse_date/master?logo=python)](
    https://gitlab.com/ae-group/ae_parse_date)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_parse_date/coverage.svg)](
    https://ae-group.gitlab.io/ae_parse_date/coverage/ae_parse_date_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_parse_date/mypy.svg)](
    https://ae-group.gitlab.io/ae_parse_date/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_parse_date/pylint.svg)](
    https://ae-group.gitlab.io/ae_parse_date/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_parse_date)](
    https://libraries.io/pypi/ae-parse-date)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_parse_date)](
    https://pypi.org/project/ae-parse-date/#files)


## installation


execute the following command to use the ae.parse_date module in your
application. it will install ae.parse_date into your python (virtual) environment:
 
```shell script
pip install ae-parse-date
```

if you instead want to contribute to this portion then first fork
[the ae_parse_date repository at GitLab](https://gitlab.com/ae-group/ae_parse_date "ae.parse_date code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_parse_date):

```shell script
pip install -e .[dev]
```

the last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.parse_date.html#module-ae.parse_date
"ae_parse_date documentation").

<!-- common files version 0.2.77 deployed version 0.2.2 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_parse_date module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-parse-date as namespace portion ae-parse-date.
-->
